@@ -1,19 +1,12 @@
 import inspect
 import re
+from typing import Tuple, Union
 
 import lab as B
 from matrix import AbstractMatrix, TiledBlocks
-from plum import (
-    Union,
-    Dispatcher,
-    Tuple,
-    parametric,
-    Signature,
-    type_of,
-    NotFoundLookupError,
-)
+from plum import Dispatcher, NotFoundLookupError, parametric
 from plum.parametric import CovariantMeta
-from varz import Vars, Struct
+from varz import Struct, Vars
 
 __all__ = [
     "Bijection",
@@ -87,10 +80,7 @@ class Bijection(metaclass=CovariantMeta):
 def transform(b: Bijection, x, *args):
     # Prevent recursion.
     if x is None:
-        sig = Signature(type_of(b), *(type_of(y) for y in (x,) + args))
-        raise NotFoundLookupError(
-            f"No bijection `transform` implementation for signature {sig}."
-        )
+        raise NotFoundLookupError(f"No bijection `transform` implementation for `{b}`.")
     return transform(b, None, x, *args)
 
 
@@ -98,9 +88,8 @@ def transform(b: Bijection, x, *args):
 def untransform(b: Bijection, y, *args):
     # Prevent recursion.
     if y is None:
-        sig = Signature(type_of(b), *(type_of(x) for x in (y,) + args))
         raise NotFoundLookupError(
-            f"No bijection `untransform` implementation for signature {sig}."
+            f"No bijection `untransform` implementation for `{b}`."
         )
     return untransform(b, None, y, *args)
 
@@ -109,10 +98,7 @@ def untransform(b: Bijection, y, *args):
 def logdet(b: Bijection, x, *args):
     # Prevent recursion.
     if x is None:
-        sig = Signature(type_of(b), *(type_of(y) for y in (x,) + args))
-        raise NotFoundLookupError(
-            f"No bijection `logdet` implementation for signature {sig}."
-        )
+        raise NotFoundLookupError(f"No bijection `logdet` implementation {b}.")
     return logdet(b, None, x, *args)
 
 
@@ -247,7 +233,6 @@ class Normaliser(Bijection):
 
         else:
             if fit:
-
                 if B.rank(x) == 0:
                     self._mean = x
                     self._scale = 1
@@ -338,7 +323,7 @@ def transform(b: Normaliser, ps: _MaybeParameters, y: Tuple[_Numeric, _Numeric])
     if B.rank(dist_var) in {0, 1, 2}:
         return (
             (dist_mean - mean) / scale,
-            dist_var / scale ** 2,
+            dist_var / scale**2,
         )
     elif B.rank(dist_var) == 3:
         scale = B.uprank(scale, rank=2)
@@ -382,7 +367,7 @@ def untransform(b: Normaliser, ps: _MaybeParameters, y: Tuple[_Numeric, _Numeric
     if B.rank(dist_var) in {0, 1, 2}:
         return (
             dist_mean * scale + mean,
-            dist_var * scale ** 2,
+            dist_var * scale**2,
         )
     elif B.rank(dist_var) == 3:
         scale = B.uprank(scale, rank=2)
@@ -426,7 +411,7 @@ def transform(b: Log, ps: _MaybeParameters, y: Tuple[_Numeric, _Numeric]):
     else:
         raise ValueError(f"Invalid rank {B.rank(log_var)} of the variance.")
     # These are the mean and variance of the log-normal distribution.
-    var = B.log(log_var / log_mean ** 2 + 1)
+    var = B.log(log_var / log_mean**2 + 1)
     return (B.log(log_mean) - 0.5 * var, var)
 
 
